@@ -1,5 +1,5 @@
 /*
- * $Id: gdbserver.c,v 1.50 2004/10/19 18:43:50 zfrdh Exp $
+ * $Id: gdbserver.c,v 1.53 2008/01/07 17:04:15 joerg_wunsch Exp $
  *
  ****************************************************************************
  *
@@ -69,7 +69,7 @@
 #ifndef DOXYGEN                 /* have doxygen system ignore this. */
 enum
 {
-    MAX_BUF        = 400,       /* Maximum size of read/write buffers. */
+    MAX_BUF        = 100000,    /* Maximum size of read/write buffers. */
     MAX_READ_RETRY = 10,        /* Maximum number of retries if a read is
                                    incomplete. */
 
@@ -610,7 +610,7 @@ gdb_read_memory (GdbComm_T *comm, int fd, char *pkt)
         /* if ( (addr >= 0) && (addr < 32) ) */
         if (0)
         {
-            snprintf (buf, len * 2, "E%02x", EIO);
+            snprintf ((char*)buf, len * 2, "E%02x", EIO);
         }
         else
         {
@@ -678,10 +678,10 @@ gdb_read_memory (GdbComm_T *comm, int fd, char *pkt)
     {
         /* gdb asked for memory space which doesn't exist */
         avr_warning ("Invalid memory address: 0x%x.\n", addr);
-        snprintf (buf, len * 2, "E%02x", EIO);
+        snprintf ((char*)buf, len * 2, "E%02x", EIO);
     }
 
-    gdb_send_reply (fd, buf);
+    gdb_send_reply (fd, (char*)buf);
 
     avr_free (buf);
 }
